@@ -3,46 +3,48 @@ from __future__ import annotations
 
 from typing import ClassVar, Optional
 
+from pyplumio.const import ATTR_EXTRA, ATTR_NAME, ATTR_VALUE
 from pyplumio.exceptions import FrameDataError
-from pyplumio.frames import Request, RequestTypes, Response, responses
+from pyplumio.frames import Request, RequestTypes, Response
+from pyplumio.frames.responses import DeviceAvailableResponse, ProgramVersionResponse
 from pyplumio.helpers.typing import DeviceDataType, MessageType
 from pyplumio.structures.boiler_parameters import BOILER_PARAMETERS
 from pyplumio.structures.mixer_parameters import MIXER_PARAMETERS
 
 
-class ProgramVersion(Request):
+class ProgramVersionRequest(Request):
     """Represents program version request."""
 
     frame_type: ClassVar[int] = RequestTypes.PROGRAM_VERSION
 
     def response(self, **kwargs) -> Optional[Response]:
         """Return response frame object."""
-        return responses.ProgramVersion(recipient=self.sender, **kwargs)
+        return ProgramVersionResponse(recipient=self.sender, **kwargs)
 
 
-class CheckDevice(Request):
+class CheckDeviceRequest(Request):
     """Represents check device request."""
 
     frame_type: ClassVar[int] = RequestTypes.CHECK_DEVICE
 
     def response(self, **kwargs) -> Optional[Response]:
         """Return response frame object."""
-        return responses.DeviceAvailable(recipient=self.sender, **kwargs)
+        return DeviceAvailableResponse(recipient=self.sender, **kwargs)
 
 
-class UID(Request):
+class UIDRequest(Request):
     """Represents uid request."""
 
     frame_type: ClassVar[int] = RequestTypes.UID
 
 
-class Password(Request):
+class PasswordRequest(Request):
     """Represents password request."""
 
     frame_type: ClassVar[int] = RequestTypes.PASSWORD
 
 
-class BoilerParameters(Request):
+class BoilerParametersRequest(Request):
     """Represents boiler parameters request."""
 
     frame_type: ClassVar[int] = RequestTypes.BOILER_PARAMETERS
@@ -50,24 +52,24 @@ class BoilerParameters(Request):
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
         message = bytearray()
-        message.append(0xFF)  # Number of parameters.
-        message.append(0x00)  # Index of parameters.
+        message.append(255)  # Number of parameters.
+        message.append(0)  # Index of the first parameter.
         return message
 
 
-class MixerParameters(Request):
+class MixerParametersRequest(Request):
     """Represents mixer parameters request."""
 
     frame_type: ClassVar[int] = RequestTypes.MIXER_PARAMETERS
 
 
-class DataSchema(Request):
+class DataSchemaRequest(Request):
     """Represents data schema request."""
 
     frame_type: ClassVar[int] = RequestTypes.DATA_SCHEMA
 
 
-class SetBoilerParameter(Request):
+class SetBoilerParameterRequest(Request):
     """Represents set boiler parameter request."""
 
     frame_type: ClassVar[int] = RequestTypes.SET_BOILER_PARAMETER
@@ -76,8 +78,8 @@ class SetBoilerParameter(Request):
         """Create frame message."""
         try:
             message = bytearray()
-            name = data["name"]
-            value = data["value"]
+            name = data[ATTR_NAME]
+            value = data[ATTR_VALUE]
             message.append(BOILER_PARAMETERS.index(name))
             message.append(value)
             return message
@@ -85,7 +87,7 @@ class SetBoilerParameter(Request):
             raise FrameDataError from e
 
 
-class SetMixerParameter(Request):
+class SetMixerParameterRequest(Request):
     """Represents set mixer parameter request."""
 
     frame_type: ClassVar[int] = RequestTypes.SET_MIXER_PARAMETER
@@ -93,9 +95,9 @@ class SetMixerParameter(Request):
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
         try:
-            name = data["name"]
-            value = data["value"]
-            index = data["extra"]
+            name = data[ATTR_NAME]
+            value = data[ATTR_VALUE]
+            index = data[ATTR_EXTRA]
             message = bytearray()
             message.append(index)
             message.append(MIXER_PARAMETERS.index(name))
@@ -105,7 +107,7 @@ class SetMixerParameter(Request):
             raise FrameDataError from e
 
 
-class BoilerControl(Request):
+class BoilerControlRequest(Request):
     """Represent boiler control request."""
 
     frame_type: ClassVar[int] = RequestTypes.BOILER_CONTROL
@@ -114,19 +116,32 @@ class BoilerControl(Request):
         """Creates frame message."""
         try:
             message = bytearray()
-            message.append(data["value"])
+            message.append(data[ATTR_VALUE])
             return message
         except KeyError as e:
             raise FrameDataError from e
 
 
-class StartMaster(Request):
+class StartMasterRequest(Request):
     """Represent start master request."""
 
     frame_type: ClassVar[int] = RequestTypes.START_MASTER
 
 
-class StopMaster(Request):
+class StopMasterRequest(Request):
     """Represent stop master request."""
 
     frame_type: ClassVar[int] = RequestTypes.STOP_MASTER
+
+
+class AlertsRequest(Request):
+    """Represent alerts request."""
+
+    frame_type: ClassVar[int] = RequestTypes.ALERTS
+
+    def create_message(self, data: DeviceDataType) -> MessageType:
+        """Create frame message."""
+        message = bytearray()
+        message.append(0)  # Index of the first alarm.
+        message.append(100)  # Number of alarms.
+        return message
